@@ -8,12 +8,13 @@ use Config;
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '0.90';
+	$VERSION = '0.92';
 	@ISA     = 'Exporter';
 	@EXPORT  = qw{
 		create_dist
 		build_dist
 		kill_dist
+		run_makefile_pl
 	};
 }
 
@@ -87,7 +88,26 @@ sub build_dist {
 	chdir $dist_path or return 0;
 	my $X_MYMETA = $params{MYMETA} || '';
 	local $ENV{X_MYMETA} = $X_MYMETA;
-	system($^X, "-I../../lib", "-I../../blib/lib", "Makefile.PL") == 0 or return 0;
+
+	my @run_params=@{ $params{run_params} || [] };
+	system($^X, "-I../../lib", "-I../../blib/lib", "Makefile.PL",@run_params) == 0 or return 0;
+	chdir $home or return 0;
+	return 1;
+}
+
+sub run_makefile_pl {
+	my $dist      = shift;
+	my %params    = @_;
+	my $dist_path = File::Spec->catdir('t', $dist);
+	return 0 unless -d $dist_path;
+	my $home = cwd;
+	chdir $dist_path or return 1;
+	my $X_MYMETA = $params{MYMETA} || '';
+	local $ENV{X_MYMETA} = $X_MYMETA;
+
+	my $run_params=join(' ',@{ $params{run_params} || [] });
+	system("$^X -I../../lib -I../../blib/lib Makefile.PL $run_params") == 0 or return 0;
+	#my $result=qx();
 	chdir $home or return 0;
 	return 1;
 }
